@@ -21,10 +21,10 @@ sh = logging.StreamHandler()
 sh.setFormatter(logging.Formatter('%(asctime)s - %(name)s - %(levelname)s - %(message)s'))
 log.addHandler(sh)
 
-#functions for reading input files
+# functions for reading input files
 from .reader import read_targets, read_sample_info
 
-#datatypes for variant summary tables
+# datatypes for variant summary tables
 variants_dtypes = {
     'Chr': str,
     'Ref': str,
@@ -50,24 +50,24 @@ def load_gene_exons(file: str, genes: list) -> dict:
     """Load list of exon chr, strand, start and end locations for each gene in genes."""
     genes = genes.unique()
 
-    #load gene exon information from flat table
+    # load gene exon information from flat table
     print('Loading exon table from ', file)
     gene_exon_df = pd.read_csv(file, header=None, sep='\t')
     gene_exon_df.rename(columns={2: 'chr', 3: 'strand', 8: 'n_exons', 9: 'exon_starts', 10: 'exon_ends', 12: 'gene'}, inplace=True)
     print('Loaded ', len(gene_exon_df), ' rows.')
 
-    #filter down to only the genes we actually need
+    # filter down to only the genes we actually need
     gene_exon_df = gene_exon_df[ gene_exon_df['gene'].isin(genes) ]
     print('Filtered to ', len(gene_exon_df), ' rows for ', len(genes), ' genes.')
 
-    #identify standard chrs
+    # identify standard chrs
     regex_standard_chr = re.compile(r'^(chr)?([0-9MXY]+)$')
 
-    #make dict of genes to exon locations
+    # make dict of genes to exon locations
     gene_exons = {}
     for gex in gene_exon_df.itertuples():
         try:
-            #skip chrY FIXME: do we want this
+            # skip chrY FIXME: do we want this
             if gex.chr == 'chrY':
                 continue
 
@@ -78,36 +78,36 @@ def load_gene_exons(file: str, genes: list) -> dict:
                 'ends': [int(x) for x in gex.exon_ends.split(',') if len(x) > 0],
             }
 
-            #do we already have exons for this gene?
+            # do we already have exons for this gene?
             if gex.gene in gene_exons:
-                #is this on the same chr (and not an Alt chr)?
+                # is this on the same chr (and not an Alt chr)?
                 if gene_exons[gex.gene]['chr'] == exon_data['chr']:
-                    #if we are on the same strand let's merge them
+                    # if we are on the same strand let's merge them
                     if gene_exons[gex.gene]['strand'] == exon_data['strand']:
                         n_total = 0
                         n_added = 0
                         for start, end in zip(exon_data['starts'], exon_data['ends']):
                             n_total += 1
 
-                            #try to find existing pair that matches
+                            # try to find existing pair that matches
                             for existing_start, existing_end in zip(gene_exons[gex.gene]['starts'], gene_exons[gex.gene]['ends']):
                                 if existing_start == start and existing_end == end:
                                     break
-                            #otherwise add it
+                            # otherwise add it
                             else:
                                 n_added += 1
                                 gene_exons[gex.gene]['starts'].append(start)
                                 gene_exons[gex.gene]['ends'].append(end)
 
-                        #log.debug('Merging exon data from duplicate rows for gene %s - added %d/%d', gex.gene, n_added, n_total)
+                        # log.debug('Merging exon data from duplicate rows for gene %s - added %d/%d', gex.gene, n_added, n_total)
                     else:
                         # print(gex.gene)
                         # print(gene_exons[gex.gene])
                         # print(exon_data)
                         raise Exception('Exon strand mismatch for {}'.format(gex.gene))
-                #if the existing copy is on a standard chr we want to keep it
+                # if the existing copy is on a standard chr we want to keep it
                 elif regex_standard_chr.match(gene_exons[gex.gene]['chr']):
-                    #normally this should only happen if we are on an alt chr now
+                    # normally this should only happen if we are on an alt chr now
                     if not regex_standard_chr.match(gex.chr):
                         # log.debug('Skipping copy of gene on nonstandard chr for gene exon table: {} @ {}/{}'.format(
                         #     gex.gene, gex.chr, gene_exons[gex.gene]['chr']
@@ -117,26 +117,26 @@ def load_gene_exons(file: str, genes: list) -> dict:
                         raise Exception('Two copies of gene on different standard chrs encounted for gene exon table: {} @ {}/{}'.format(
                             gex.gene, gex.chr, gene_exons[gex.gene]['chr']
                         ))
-                #if the existing copy was not on a standard chr we will just overwrite it with this copy
+                # if the existing copy was not on a standard chr we will just overwrite it with this copy
                 else:
                     pass
                     # log.debug('Overwriting copy of gene on nonstandard chr for gene exon table: {} @ {}/{}'.format(
                     #     gex.gene, gex.chr, gene_exons[gex.gene]['chr']
                     # ))
 
-            #error checking
+            # error checking
             assert len(exon_data['starts']) == len(exon_data['ends'])
             assert len(exon_data['starts']) == gex.n_exons
             for start, end in zip(exon_data['starts'], exon_data['ends']):
                 assert end > start, 'Exon end is not after start for {}'.format(gex.gene)
 
-            #finally save the exon data
+            # finally save the exon data
             gene_exons[gex.gene] = exon_data
         except Exception as e:
             print('Igoring error while processing exon data: {}'.format(
                 str(e)))
 
-    #make sure we found exons for every gene
+    # make sure we found exons for every gene
     missing_genes = set(genes) - set(gene_exons.keys())
     if len(missing_genes) > 0:
         print('Failed to find exon location information for: %s' % (','.join(missing_genes)))
@@ -156,15 +156,15 @@ def find_closest_exon(row: pd.Series, gexs: dict) -> int:
     gex = gexs[row['Gene.refGene']]
     assert (row['Chr'] == gex['chr']) or (row['Chr'] == 'chr'+gex['chr']) or ('chr'+row['Chr'] == gex['chr'])
 
-    #upstream of start = negative, downstream of end = positive
+    # upstream of start = negative, downstream of end = positive
     start_dist = [row['End'] - boundary_pos for boundary_pos in gex['starts'] if boundary_pos >= row['End']]
     end_dist = [row['Start'] - boundary_pos for boundary_pos in gex['ends'] if boundary_pos <= row['Start']]
 
-    #find smallest abs(value) for each
+    # find smallest abs(value) for each
     closest_start = max(start_dist) if len(start_dist) > 0 else None
     closest_end = min(end_dist) if len(end_dist) > 0 else None
 
-    #figure out whether we are closer to start or end
+    # figure out whether we are closer to start or end
     if closest_start is None and closest_end is None:
         closest_distance = None
     elif closest_start is None:
@@ -174,7 +174,7 @@ def find_closest_exon(row: pd.Series, gexs: dict) -> int:
     else:
         closest_distance = closest_start if abs(closest_start) < closest_end else closest_end
 
-    #if gene strand is negative it's actually the opposite
+    # if gene strand is negative it's actually the opposite
     if closest_distance is None:
         return None
     elif gex['strand'] == '+':
@@ -184,7 +184,7 @@ def find_closest_exon(row: pd.Series, gexs: dict) -> int:
     else:
         raise Exception('Invalid strand')
 
-#see: /hts/data6/smcgowan/hts_scripts/TableAnnovar_to_spreadsheet.pl
+# see: /hts/data6/smcgowan/hts_scripts/TableAnnovar_to_spreadsheet.pl
 def calculate_del_score(merged: pd.DataFrame):
     """
     Add a column DeleteriousScore to dataframe which contains a count of how many tools have assigned this variant a deletious scores.
@@ -210,7 +210,7 @@ def calculate_del_score(merged: pd.DataFrame):
         assert merged['phyloP100way_vertebrate'].dtype == float
         merged.loc[merged['phyloP100way_vertebrate'] > 1, 'DeleteriousScore'] += 1
 
-    #set score = 6 for some special cases
+    # set score = 6 for some special cases
     if 'ExonicFunc.refGene' in merged.columns:
         merged.loc[merged['ExonicFunc.refGene'].notnull() & merged['ExonicFunc.refGene'].str.contains('^stopgain|^frameshift'), 'DeleteriousScore'] = 6
         merged.loc[merged['ExonicFunc.refGene'].notnull() & merged['ExonicFunc.refGene'].str.contains('splic'), 'DeleteriousScore'] = 6
@@ -294,17 +294,17 @@ def merge_variants_unannotated(input_vcfs, output_file):
 def make_summary(input: list, output: list, config: dict, exon_table_path: str = None):
     """Load merged Annovar CSV file (plus targets and sample info), process them and output a new CSV file."""
 
-    #load targets (to add a targets column)
+    # load targets (to add a targets column)
     targets = None
     if len(input['targets']) > 0:
         targets = read_targets(input['targets'], file_type = 'bed', reference_type = 'genome')
 
-    #load sample information table
+    # load sample information table
     sample_info = None
     if len(input['sample_info']) > 0:
         sample_info = read_sample_info(input['sample_info'][0])
 
-    #load merged variant table, process it and write to CSV
+    # load merged variant table, process it and write to CSV
     try:
         merged = pd.read_csv(input['merged'], index_col = False, dtype = variants_dtypes, na_values = variants_na_values)
         merged = make_summary_dataframe(
@@ -339,7 +339,7 @@ def make_summary_dataframe(
     if targets is not None:
         target_intervals = collections.defaultdict(interlap.InterLap)
         for target in targets.itertuples():
-            target_intervals[target.chr].add( (int(target.start_0), int(target.end), target) ) #note the double parentheses!
+            target_intervals[target.chr].add( (int(target.start_0), int(target.end), target) ) # note the double parentheses!
 
     # process sample information table
     sample_info_columns = []
@@ -348,7 +348,7 @@ def make_summary_dataframe(
 
     # read original data from VCF columns
     vcf = merged['Otherinfo' if 'Otherinfo' in merged.columns else 'Otherinfo1'].apply(lambda x: pd.Series(x.split('\t')))
-    vcf.replace('.', np.nan, inplace=True) #replace dots with NAs again
+    vcf.replace('.', np.nan, inplace=True) # replace dots with NAs again
     vcf.columns = ['Chr', 'Pos', 'ID', 'Ref', 'Alt', 'Qual', 'Filter', 'Info', 'Fields', 'SampleData']
 
     # fix types
@@ -392,7 +392,7 @@ def make_summary_dataframe(
 
     # get gt info
     vcf_sample = pd.DataFrame([ dict( zip( row.Fields.split(':'), row.SampleData.split(':') ) ) for row in vcf.itertuples() ])
-    vcf_sample.replace('.', np.nan, inplace=True) #replace dots with NAs again
+    vcf_sample.replace('.', np.nan, inplace=True) # replace dots with NAs again
 
     # parse out some fields
     vcf_infos = vcf['Info'].apply(lambda x: pd.Series(dict( [ tuple(pair.split('=')) if '=' in pair else (pair, True) for pair in x.split(';') ] )))
@@ -402,10 +402,11 @@ def make_summary_dataframe(
         vcf_infos.loc[vcf_infos['NF'].str.contains(','), 'NF'] = '-1'
         vcf_infos.loc[vcf_infos['NR'].str.contains(','), 'NR'] = '-1'
     if 'NR' in vcf_sample:
-        vcf_sample.loc[vcf_sample['NR'].str.contains(','), 'NR'] = '-1' #also need to fix this, for assertion below
-        vcf_sample.loc[vcf_sample['NV'].str.contains(','), 'NV'] = '-1' #also need to fix this, for assertion below
+        vcf_sample.loc[vcf_sample['NR'].str.contains(','), 'NR'] = '-1' # also need to fix this, for assertion below
+        vcf_sample.loc[vcf_sample['NV'].str.contains(','), 'NV'] = '-1' # also need to fix this, for assertion below
+
     # now rename coverage fields and convert to ints
-    have_fwd_ref = False
+    have_fwd_rev = False
     vcf_infos['Total_Coverage'] = -1
     vcf_infos['Total_Coverage_fwd'] = -1
     vcf_infos['Total_Coverage_rev'] = -1
@@ -413,28 +414,32 @@ def make_summary_dataframe(
     vcf_infos['Total_Reads_Alt_fwd'] = -1
     vcf_infos['Total_Reads_Alt_rev'] = -1
 
-    # PLATYPUS will give us TC/TR
+    # platypus will give us TC/TR
     if 'TC' in vcf_infos:
-        have_fwd_ref = True
         vcf_infos['Total_Coverage'] = vcf_infos['TC'].astype(int)
+    elif 'DP' in vcf_sample:
+        # GATK/octopus will give us DP
+        vcf_infos['Total_Coverage'] = vcf_sample['DP'].astype(int)
+    elif 'AD' in vcf_sample:
+        # mutect2 won't
+        vcf_infos['Total_Coverage'] = [int(x.split(',')[0]) + int(x.split(',')[1]) for x in vcf_sample['AD']]
+
+    if 'TCF' in vcf_infos:
+        have_fwd_rev = True
         vcf_infos['Total_Coverage_fwd'] = vcf_infos['TCF'].astype(int)
         vcf_infos['Total_Coverage_rev'] = vcf_infos['TCR'].astype(int)
+
     if 'TR' in vcf_infos:
         vcf_infos['Total_Reads_Alt'] = vcf_infos['TR'].astype(int)
+
+    if 'NF' in vcf_infos:
         vcf_infos['Total_Reads_Alt_fwd'] = vcf_infos['NF'].astype(int)
         vcf_infos['Total_Reads_Alt_rev'] = vcf_infos['NR'].astype(int)
 
     # GATK will give us an AD value
     if 'AD' in vcf_sample:
-        have_fwd_ref = False
         vcf_infos['Total_Reads_Ref'] = [int(x.split(',')[0]) for x in vcf_sample['AD']]
         vcf_infos['Total_Reads_Alt'] = [int(x.split(',')[1]) for x in vcf_sample['AD']]
-        if 'DP' in vcf_sample:
-            #gatk will give us DP
-            vcf_infos['Total_Coverage'] = vcf_sample['DP'].astype(int)
-        else:
-            #mutect2 won't
-            vcf_infos['Total_Coverage'] = [int(x.split(',')[0]) + int(x.split(',')[1]) for x in vcf_sample['AD']]
 
     # some error checking
     if ((vcf_infos['Total_Coverage_fwd'] != -1) & (vcf_infos['Total_Coverage_rev'] != -1)).any():
@@ -448,7 +453,7 @@ def make_summary_dataframe(
 
     # add info from VCF to table
     merged['Var_Zygosity'] = ['HOM' if gt == '1/1' else 'Het' if gt in ['0/1', '1/0'] else 'REF' if gt in ['0/0'] else '???' for gt in vcf_sample['GT']]
-    merged['Var_FailedFilters'] = ['' if (filt == 'PASS' or filt == '.') else filt for filt in vcf['Filter']]
+    merged['Var_FailedFilters'] = ['' if (filt == 'PASS' or filt == '.' or pd.isna(filt)) else filt for filt in vcf['Filter']]
     # mutect2 gives us AF
     if 'AF' in vcf_sample:
         merged['Var_AltFraction'] = [float(x.split(',')[0]) for x in vcf_sample['AF']]
@@ -456,11 +461,11 @@ def make_summary_dataframe(
         merged['Var_AltFraction'] = 1.0 * vcf_infos['Total_Reads_Alt'] / vcf_infos['Total_Coverage']
         merged.loc[vcf_infos['Total_Reads_Alt'] == -1, 'Var_AltFraction'] = None
     merged['Var_TotalCoverage'] = vcf_infos['Total_Coverage']
-    if have_fwd_ref:
+    if have_fwd_rev:
         merged['Var_Ref_fwd'] = (vcf_infos['Total_Coverage_fwd'] - vcf_infos['Total_Reads_Alt_fwd'])
         merged['Var_Ref_rev'] = (vcf_infos['Total_Coverage_rev'] - vcf_infos['Total_Reads_Alt_rev'])
     merged['Var_Alt'] = vcf_infos['Total_Reads_Alt']
-    if have_fwd_ref:
+    if have_fwd_rev:
         merged['Var_Alt_fwd'] = vcf_infos['Total_Reads_Alt_fwd']
         merged['Var_Alt_rev'] = vcf_infos['Total_Reads_Alt_rev']
     merged['Var_QualVariant'] = vcf['Qual'].astype(float)
@@ -471,7 +476,10 @@ def make_summary_dataframe(
     merged['Comments'] = ''
 
     # manually add filter status for low coverage
-    merged.loc[merged['Var_TotalCoverage'] < 10, 'Var_FailedFilters'] = [filt + ';CovLt10' if len(filt) > 0 else 'CovLt10' for filt in merged.loc[merged['Var_TotalCoverage'] < 10, 'Var_FailedFilters']]
+    merged.loc[merged['Var_TotalCoverage'] < 10, 'Var_FailedFilters'] = [
+        filt + ';CovLt10' if len(filt) > 0 else 'CovLt10'
+        for filt in merged.loc[merged['Var_TotalCoverage'] < 10, 'Var_FailedFilters']
+    ]
 
     # calculate the deleteriousness score
     if include_score:
@@ -521,7 +529,7 @@ def make_summary_dataframe(
     for db_prefix in ['ExAC', 'gnomAD_genome', 'gnomAD_exome']:
         merged.drop([column for column in merged.columns if column.startswith(db_prefix) and not column.endswith('_ALL')], axis=1, inplace=True)
 
-    #first columns
+    # first columns
     first_cols = []
     if include_score:
         first_cols.append('DeleteriousScore')
@@ -531,26 +539,26 @@ def make_summary_dataframe(
         first_cols.append('DistanceNearestExon')
     first_cols = first_cols + [c for c in merged.columns if c.startswith('Var_') and c != 'Var_Qual']
 
-    #last columns
+    # last columns
     last_cols = ['Chr', 'Start', 'End', 'Ref', 'Alt']
     if include_gbrowse_links:
         last_cols.append('GBrowse')
     last_cols += ['Sample'] + sample_info_columns + ['Comments']
 
-    #columns to remove
+    # columns to remove
     ignored_cols = ['GeneDetail.refGene']
 
-    #select and reorder columns
+    # select and reorder columns
     merged.sort_values(['Sample', 'Chr', 'Start'], inplace=True)
     merged = merged[first_cols + [c for c in merged.columns if not c in first_cols + last_cols + ignored_cols] + last_cols]
 
-    #output
+    # output
     return merged
 
 def make_summary_condensed(input, output):
     """Make condensed summary table that only contains a subset of columns."""
 
-    #load sample information table
+    # load sample information table
     sample_info_columns = []
     if len(input['sample_info']) > 0:
         sample_info = read_sample_info(input['sample_info'][0])
@@ -558,10 +566,10 @@ def make_summary_condensed(input, output):
 
     for do_filter in ['filtered', 'unfiltered']:
         try:
-            #load
+            # load
             merged = pd.read_csv(input['summary'], index_col = False, dtype = variants_dtypes, na_values = variants_na_values)
 
-            #filter
+            # filter
             if do_filter == 'filtered':
                 print('Got %d rows with %d passing filters and %d coverage >= 10' % (len(merged), (merged['Var_FailedFilters'].isnull()).sum(), (merged['Var_TotalCoverage'] >= 10).sum()))
                 merged = merged[ (merged['Var_FailedFilters'].isnull()) & (merged['Var_TotalCoverage'] >= 10) ]
@@ -569,25 +577,25 @@ def make_summary_condensed(input, output):
             else:
                 print('Not filtering, got %d rows' % len(merged))
 
-            #find column with dbsnp-id (taking first that starts with avsnp)
+            # find column with dbsnp-id (taking first that starts with avsnp)
             avsnp_columns = [c for c in merged.columns if c.startswith('avsnp')]
             if len(avsnp_columns) > 0:
                 merged['ID_dbsnp'] = merged[avsnp_columns[0]]
-            #rename column
+            # rename column
             merged['Genotype'] = merged['Var_Zygosity']
-            #get desired columns
+            # get desired columns
             output_columns = ([] if do_filter == 'filtered' else ['Var_FailedFilters']) + [
                     'Sample', 'Target',
                     'Chr', 'Start', 'Ref', 'Alt', 'Genotype',
                     'ID_dbsnp', 'DeleteriousScore',
                     'Gene.refGene', 'Func.refGene', 'ExonicFunc.refGene', 'AAChange.refGene'
                 ] + sample_info_columns
-            #make sure the columns actually exist
+            # make sure the columns actually exist
             output_columns = [c for c in output_columns if c in merged.columns]
 
             merged = merged[output_columns]
 
-            #output
+            # output
             merged.to_csv(output[do_filter], index = False)
         except pd.errors.EmptyDataError:
             print('No variants found, creating empty file!')
@@ -600,10 +608,10 @@ def make_summary_condensed(input, output):
 #     try:
 #         merged = pd.read_csv(input[0], index_col = False)
 
-#         #reset header format
+#         # reset header format
 #         pd.formats.format.header_style = None
 
-#         #requires openpyxl
+#         # requires openpyxl
 #         with pd.ExcelWriter(output[0]) as xlsx:
 #             merged.to_excel(xlsx, sheet_name='All (%d)' % len(merged))
 
@@ -633,14 +641,14 @@ def make_summary_condensed(input, output):
 #                     my_merged.drop('_sheet', axis=1, inplace=True)
 #                     my_merged.to_excel(xlsx, sheet_name='%s (%d)' % (sheet, len(my_merged)))
 
-#             #add formatting
+#             # add formatting
 #             workbook = xlsx.book
 #             for worksheet in workbook:
-#                 #http://openpyxl.readthedocs.io/en/default/api/openpyxl.worksheet.worksheet.html
-#                 #http://openpyxl.readthedocs.io/en/default/formatting.html
-#                 #add colour scale on deleteriousness score
+#                 # http://openpyxl.readthedocs.io/en/default/api/openpyxl.worksheet.worksheet.html
+#                 # http://openpyxl.readthedocs.io/en/default/formatting.html
+#                 # add colour scale on deleteriousness score
 #                 worksheet.conditional_formatting.add('A1:A%d'%worksheet.max_row, openpyxl.formatting.rule.ColorScaleRule(start_color = 'ffffff', end_color = 'aa0000'))
-#                 #causes error, not clear why...
+#                 # causes error, not clear why...
 #                 pass
 
 #             xlsx.save()
