@@ -2,7 +2,7 @@
 This does some basic testing of the whole pipeline. Note this needs to be run through pytest and doesn't use unittest.
 """
 
-#make sure we can import from package directory
+# make sure we can import from package directory
 import sys, os, re, gzip
 packagedir = os.path.dirname(os.path.dirname(os.path.abspath(__file__)))
 sys.path.insert(0, packagedir)
@@ -14,13 +14,23 @@ import pandas as pd
 
 import amplimap.run
 
-#we need to build the cython file here, since snakemake will call an external python that wouldn't
-#inherit pyximport
+# we need to build the cython file here, since snakemake will call an external python that wouldn't
+# inherit pyximport
 os.system("cythonize -i {}".format(os.path.join(packagedir, "amplimap", "parse_reads_cy.pyx")))
 
-#set config
+# set config
 test_config_path = os.path.join(packagedir, "sample_data", "config_default.yaml")
 os.environ['AMPLIMAP_CONFIG'] = test_config_path
+test_config_raw = f'''
+paths:
+  ecoli:
+    bwa: "{os.path.join(packagedir, "sample_data")}/ecoli.fasta"
+    bowtie2: "{os.path.join(packagedir, "sample_data")}/ecoli.fasta"
+    fasta: "{os.path.join(packagedir, "sample_data")}/ecoli.fasta"
+general:
+  genome_name: "ecoli"
+'''
+
 
 def init_wd(path, reads_in_path, umi_one = 0, umi_two = 0, remove_analysis = True):
     assert os.path.isdir(path)
@@ -36,7 +46,7 @@ def init_wd(path, reads_in_path, umi_one = 0, umi_two = 0, remove_analysis = Tru
     shutil.rmtree(os.path.join(path, 'reads_in'), ignore_errors=True)
     os.mkdir(os.path.join(path, 'reads_in'))
 
-    #turn .fastq files into .fastq.gz
+    # turn .fastq files into .fastq.gz
     for file in os.listdir(reads_in_path):
         if umi_one > 0 and '_R1' in file:
             umi_len = umi_one
@@ -152,7 +162,7 @@ def test_config_env_invalid(capsys):
     assert 'Your configuration file(s) contain unknown or invalid settings:' in captured.err
 
 def check_run(capsys, wd_path, rules=['pileups'], run=True):
-    #dry-run
+    # dry-run
     assert amplimap.run.main(['--working-directory={}'.format(wd_path)] + rules) == 0
     captured = capsys.readouterr()
     assert '{} {} dry run successful.'.format(amplimap.run.__title__, amplimap.run.__version__) in captured.err.strip()
@@ -178,26 +188,26 @@ def check_default_stats(wd_path, is_trimmed=True):
 def check_default_pileups(wd_path, expected_coverage = 5, include_too_short = False):
     pileups = pd.read_csv(os.path.join(wd_path, 'analysis', 'pileups', 'pileups_long.csv'))
 
-    #we covered 11bp
+    # we covered 11bp
     assert len(pileups) == 11
 
-    #we should have 5 reads, except for the raw alignments where we include the pair with short r1/r2
+    # we should have 5 reads, except for the raw alignments where we include the pair with short r1/r2
     pileups['expected_coverage'] = expected_coverage
     if include_too_short:
         pileups.loc[(pileups.pos <= 32) | (pileups.pos >= 39), 'expected_coverage'] += 1
 
-    #everything but 35/37 should be ref
+    # everything but 35/37 should be ref
     assert pileups.loc[~pileups.pos.isin([35,37]), 'alts'].isnull().all()
     assert (pileups.loc[~pileups.pos.isin([35,37]), 'ref_hq_count'] == pileups.loc[~pileups.pos.isin([35,37]), 'expected_coverage']).all()
     assert (pileups.loc[~pileups.pos.isin([35,37]), 'nonref_hq_count'] == 0).all()
 
-    #only these should be nonref (36 is low-quality in one read)
+    # only these should be nonref (36 is low-quality in one read)
     assert pileups.loc[pileups.pos.isin([35,37]), 'alts'].notnull().all()
-    #one read from L001, one from L002
+    # one read from L001, one from L002
     assert (pileups.loc[pileups.pos == 35, 'nonref_hq_count'] == 2).all()
     assert (pileups.loc[pileups.pos == 35, 'ref_hq_count'] == pileups.loc[pileups.pos == 35, 'expected_coverage'] - 2).all()
     assert (set(pileups.loc[pileups.pos == 35, 'alts'].iloc[0].split(';')) == set(['A', 'G'])) #explicitly use iloc and no .all() here
-    #just one in L001
+    # just one in L001
     assert (pileups.loc[pileups.pos == 37, 'nonref_hq_count'] == 1).all()
     assert (pileups.loc[pileups.pos == 37, 'ref_hq_count'] == pileups.loc[pileups.pos == 37, 'expected_coverage'] - 1).all()
     assert (set(pileups.loc[pileups.pos == 37, 'alts'].iloc[0].split(';')) == set(['G'])) #explicitly use iloc and no .all() here
@@ -341,7 +351,7 @@ def test_naive_pileups_notrim(capsys):
 
     check_run(capsys, wd_path)
     check_default_stats(wd_path, is_trimmed = False)
-    #check_default_pileups(wd_path, expected_coverage = 6)
+    # check_default_pileups(wd_path, expected_coverage = 6)
 
 
 def test_bwa_pileups(capsys):
@@ -359,7 +369,7 @@ def test_bwa_pileups_notrim(capsys):
 
     check_run(capsys, wd_path)
     check_default_stats(wd_path, is_trimmed = False)
-    #check_default_pileups(wd_path, expected_coverage = 6)
+    # check_default_pileups(wd_path, expected_coverage = 6)
 
 
 def test_raw_read_pileups(capsys):
@@ -368,7 +378,7 @@ def test_raw_read_pileups(capsys):
 
     check_run(capsys, wd_path)
 
-    #check custom stats
+    # check custom stats
     samples = pd.read_csv(os.path.join(wd_path, 'analysis', 'reads_parsed', 'stats_samples.csv'))
     assert len(samples) == 1
 
@@ -380,6 +390,41 @@ def test_raw_read_pileups(capsys):
 
     check_default_pileups(wd_path, include_too_short = True)
 
+def test_variants_octopus(tmp_path, capsys):
+    wd_path = str(tmp_path / "wd_octopus")
+    shutil.copytree(os.path.join(packagedir, "sample_data", "wd_bwa"), wd_path)
+    init_wd(wd_path, os.path.join(packagedir, "sample_data", "sample_reads_in"))
+
+    cfg = tmp_path / "config.yaml"
+    cfg.write_text(f'''
+{test_config_raw}
+variants:
+  caller: octopus
+    ''')
+
+    extra_config_path = str(cfg)
+    os.environ['AMPLIMAP_CONFIG'] = extra_config_path
+    check_run(capsys, wd_path, rules=['variants'])
+    os.environ['AMPLIMAP_CONFIG'] = test_config_path # reset, so we don't affect later tests
+
+    # check octopus calls
+    with open(os.path.join(wd_path, 'analysis', 'variants_raw', 'S1.vcf')) as vcf:
+        for line in vcf:
+            if 'octopus' in line:
+                break
+        else:
+            assert False
+
+    # check custom stats
+    variants = pd.read_csv(os.path.join(wd_path, 'analysis', 'variants_raw', 'variants_summary.csv'))
+    assert len(variants) == 1
+
+    assert variants.Chr.iloc[0] == 'U00096.3'
+    assert variants.Start.iloc[0] == 35
+    assert variants.Ref.iloc[0] == 'T'
+    assert variants.Alt.iloc[0] == 'A'
+    assert variants.Var_TotalCoverage.iloc[0] == 2
+
 
 def test_umi_pileups(capsys):
     wd_path = os.path.join(packagedir, "sample_data", "wd_umis")
@@ -389,7 +434,7 @@ def test_umi_pileups(capsys):
     check_default_stats(wd_path)
     check_default_pileups(wd_path, expected_coverage=4) #one less, because two read pairs have same umi!
 
-    #check umi-specific stats
+    # check umi-specific stats
     stats_reads = pd.read_csv(os.path.join(wd_path, 'analysis', 'reads_parsed', 'stats_reads.csv'))
     assert len(stats_reads) == 1
     assert stats_reads.loc[0, 'sample'] == 'S1'
@@ -406,11 +451,11 @@ def test_umi_dedup(capsys):
     check_run(capsys, wd_path, rules = ['dedup_bams'])
 
     import pysam
-    #before dedup we had five aligned read pairs
+    # before dedup we had five aligned read pairs
     n_in = pysam.AlignmentFile(os.path.join(wd_path, 'analysis', 'bams', 'S1.bam')).count(until_eof=True)
     assert n_in == 5 * 2
 
-    #after dedup we have four (two read pairs have same UMI)
+    # after dedup we have four (two read pairs have same UMI)
     n_dedup = pysam.AlignmentFile(os.path.join(wd_path, 'analysis', 'bams_umi_dedup', 'S1.bam')).count(until_eof=True)
     assert n_dedup == 4 * 2
 
@@ -420,7 +465,7 @@ def test_naive_pileups_simulation(capsys):
     init_wd(wd_path, os.path.join(packagedir, "sample_data", "sample_reads_in"))
     shutil.rmtree(os.path.join(wd_path, 'test__GGCAATATGT_GGCAATCTGT_100'), ignore_errors=True) #make sure this doesn't exist
 
-    #run simulation, replacing A@30 to C
+    # run simulation, replacing A@30 to C
     assert amplimap.run.main(['--working-directory={}'.format(wd_path), 'test__GGCAATATGT_GGCAATCTGT_100/test_pileups.done', '--run']) == 0
     captured = capsys.readouterr()
     assert '{} {} finished!'.format(amplimap.run.__title__, amplimap.run.__version__) in captured.err.strip()
@@ -428,7 +473,7 @@ def test_naive_pileups_simulation(capsys):
     pileups = pd.read_csv(os.path.join(wd_path, 'test__GGCAATATGT_GGCAATCTGT_100', 'pileups', 'pileups_long.csv'))
     assert len(pileups) == 11
 
-    #we should have an A>C SNP at pos 30, in addition to the others
+    # we should have an A>C SNP at pos 30, in addition to the others
     assert pileups.loc[~pileups.pos.isin([30, 35, 37]), 'alts'].isnull().all()
     assert (pileups.loc[pileups.pos == 30, 'nonref_hq_count'] == 5).all()
     assert (pileups.loc[pileups.pos == 30, 'ref_hq_count'] == 0).all()
